DeferredUvCopy

Struct DeferredUvCopy 

pub struct DeferredUvCopy {
    pub src: u32,
    pub dst: u32,
    pub uv_scale: [f32; 2],
}
Records that the uv rect block at dst must be overwritten with the block at src once the renderer has resolved external images.

TODO: This is a hack. At the end of frame building we resolve UVs from the render task graph, however this is too early to resolve the real UVs for external images (happens on the renderer thread). So this is an even-more- deferred step on top of the already deferred blocks. It would be cleaner to move the existing deferred mechanism later and avoid stacking another one on top, but the better fix would be to not write UV rects in the gpu buffer and pass render task handles to the quad shaders.

Fields

src: u32dst: u32uv_scale: [f32; 2]

Per-axis scale applied to the copied uv rect. Used to convert the renderer’s normalized uvs (for external images that use them) into the device pixels that the quad shaders expect. [1.0, 1.0] for uvs that are already in device pixels.