#[repr(transparent)]pub struct GpuBufferHandle(u32);Expand description
GpuBuffer handle is similar to GpuBufferAddress with additional checks to avoid accidentally using the same handle in multiple frames.
Do not send GpuBufferHandle to the GPU directly. Instead use a GpuBuffer or GpuBufferBuilder to resolve the handle into a GpuBufferAddress that can be placed into GPU data.
The extra checks consists into storing an 8 bit epoch in the upper 8 bits of the handle. The epoch will be reused every 255 frames so this is not a mechanism that one can rely on to store and reuse handles over multiple frames. It is only a mechanism to catch mistakes where a handle is accidentally used in the wrong frame and panic.
Tuple Fields
0: u32Implementations
Sourceimpl GpuBufferHandle
impl GpuBufferHandle
pub const INVALID: GpuBufferHandle
const EPOCH_MASK: u32 = 0xFC000000
fn new(addr: u32, epoch: u32) -> Self
pub fn address_unchecked(&self) -> GpuBufferAddress